Struct BlockchainTxInfo

pub struct BlockchainTxInfo {
    pub previous_block_info: BlockInfo,
    pub current_block_info: BlockInfo,
    pub contract_balance: BigUint,
    pub contract_dcdt: HashMap<Vec<u8>, BigUint>,
    pub contract_owner: Option<Address>,
}
Some data to get copied for the tx. Would be nice maybe at some point to have a reference to the full blockchain mock in the tx context, but for now, copying some data is enough.

Fields

previous_block_info: BlockInfocurrent_block_info: BlockInfocontract_balance: BigUintcontract_dcdt: HashMap<Vec<u8>, BigUint>contract_owner: Option<Address>