pub struct BlockchainTxInfo {
pub previous_block_info: BlockInfo,
pub current_block_info: BlockInfo,
pub contract_balance: BigUint,
pub contract_dcdt: HashMap<Vec<u8>, BigUint>,
pub contract_owner: Option<Address>,
}Expand description
Some data to get copied for the tx. Would be nice maybe at some point to have a reference to the full blockchain mock in the tx context, but for now, copying some data is enough.
Fields
previous_block_info: BlockInfocurrent_block_info: BlockInfocontract_balance: BigUintcontract_dcdt: HashMap<Vec<u8>, BigUint>contract_owner: Option<Address>Trait Implementations
Sourceimpl Clone for BlockchainTxInfo
impl Clone for BlockchainTxInfo
Sourcefn clone(&self) -> BlockchainTxInfo
fn clone(&self) -> BlockchainTxInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for BlockchainTxInfo
impl RefUnwindSafe for BlockchainTxInfo
impl Send for BlockchainTxInfo
impl Sync for BlockchainTxInfo
impl Unpin for BlockchainTxInfo
impl UnwindSafe for BlockchainTxInfo